# mt-ban-ascii.pl
# - Deny or moderate ASCII or Latin-1 comment using MT3 CommentFilter API
#
# It requires Perl 5.8 or over.
#
# Author:  Tatsuhiko Miyagawa <miyagawa at bulknews.net>
# License: same as Perl
#
# Ported to MT 3.x TBPingThrottleFilter by Yujiro ARAKI.
# asciiTBPingfilter.pl
# 2006.07.17 1.00
# 2007.09.14 2.00 for Movable Type 4

package MT::Plugin::asciiTBPingfilter;

use strict;
use warnings;

use base qw(MT::Plugin);

our $VERSION = '2.0';
our $asciiTBPingfilter;
our $log;

my $plugin = MT::Plugin::asciiTBPingfilter->new ({
    id   => 'ASCII TBPing Filter Plugin',
    name => 'ASCII TBPing Filter Plugin',
    description => '<MT_TRANS phrase="Filter only ascii trackback ping.">',
    plugin_link => 'http://www.koikikukan.com/archives/2006/07/25-013333.php',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    version => $VERSION,
    blog_config_template => 'config.tmpl',
    settings => new MT::PluginSettings ([
        ['asciiTBPingfilter', { Default => 1, Scope => 'blog' }],
        ['asciiTBPingfilterLog', { Default => '', Scope => 'blog' }],
    ]),
    l10n_class => 'asciiTBPingfilter::L10N',
});
MT->add_plugin($plugin);
MT->add_callback('TBPingThrottleFilter', 5, $plugin, sub { ascii_tbping_filter($plugin, @_) });

sub ascii_tbping_filter {
    my $plugin = shift;
    my($eh, $app, $tb) = @_;

    my $id = $app->blog->id if $app->blog;
    return 1 unless $plugin->get_config_value('asciiTBPingfilter', "blog:$id");
    $log = $plugin->get_config_value('asciiTBPingfilterLog', "blog:$id");

    my $q = $app->{query};
    my $tbping = MT::TBPing->new;
    $tbping->title($q->param('title') || '');
    $tbping->excerpt($q->param('excerpt') || '');
    $tbping->blog_name($q->param('blog_name') || '');

    eval { require Encode; };
    if ($@) {
        $app->log("Please use perl 5.8 for this plugin.");
        return 1;
    }
    my $text = Encode::decode(MT::ConfigMgr->instance->PublishCharset, $tbping->all_text);
    if ($text =~ /^[\x00-\xff]+$/) {
        $app->log($plugin->translate('Filter ascii trackback ping.') . "URL:" . $q->param('url') . " IP:" . $app->remote_ip) if $log;
        return 0;
    }
    return 1;
}

1;
